summaryrefslogtreecommitdiff
path: root/FreeRTOS/Demo
diff options
context:
space:
mode:
authorrtel <rtel@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2016-04-04 14:53:04 +0000
committerrtel <rtel@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2016-04-04 14:53:04 +0000
commite90329865b5e0a8ed6391a2d05ef863139dd5533 (patch)
tree54434cb9a50dfe9d432c6e92467cf7104d43f8c1 /FreeRTOS/Demo
parent05067b72f3b2b6e82faf5c01e515442448633ab5 (diff)
downloadfreertos-e90329865b5e0a8ed6391a2d05ef863139dd5533.tar.gz
Correct comment error that was replicated on many different main_full.c files.
git-svn-id: http://svn.code.sf.net/p/freertos/code/trunk@2438 1d2547de-c912-0410-9cb9-b8ca96c0e9e2
Diffstat (limited to 'FreeRTOS/Demo')
-rw-r--r--FreeRTOS/Demo/CORTEX_A53_64-bit_UltraScale_MPSoC/RTOSDemo_A53/src/Full_Demo/main_full.c18
-rw-r--r--FreeRTOS/Demo/CORTEX_A5_SAMA5D3x_Xplained_IAR/Full_Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_A5_SAMA5D4x_EK_IAR/Full_Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_A9_Cyclone_V_SoC_DK/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_A9_RZ_R7S72100_IAR_DS-5/Source/Full-Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_A9_Zynq_ZC702/RTOSDemo/src/Full_Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/Full_Demo/main_full.c16
-rw-r--r--FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/ReadMe_Instructions.url5
-rw-r--r--FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/FreeRTOSConfig.h2
-rw-r--r--FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/Full_Demo/main_full.c16
-rw-r--r--FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/ReadMe_Instructions.url5
-rw-r--r--FreeRTOS/Demo/CORTEX_M4F_CEC1302_Keil/peripheral_library/cfg.h327
-rw-r--r--FreeRTOS/Demo/CORTEX_M4F_MSP432_LaunchPad_IAR_CCS_Keil/Full_Demo/main_full.c16
-rw-r--r--FreeRTOS/Demo/CORTEX_M7_SAME70_Xplained_AtmelStudio/src/Full_Demo/main_full.c20
-rw-r--r--FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_AtmelStudio/Full_Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_IAR_Keil/Full_Demo/main_full.c22
-rw-r--r--FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c20
-rw-r--r--FreeRTOS/Demo/CORTEX_R4F_RZ_T_GCC_IAR/src/Full_Demo/main_full.c16
-rw-r--r--FreeRTOS/Demo/MicroBlaze_Kintex7_EthernetLite/RTOSDemo/src/Full_Demo/main_full.c18
-rw-r--r--FreeRTOS/Demo/RX100_RX113-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/RX100_RX113-RSK_Renesas_e2studio/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/RX200_RX231-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/RX200_RX231-RSK_Renesas_e2studio/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/RX600_RX64M_RSK_GCC_e2studio/src/main_full.c22
-rw-r--r--FreeRTOS/Demo/RX600_RX64M_RSK_Renesas_e2studio/Source/main_full.c22
-rw-r--r--FreeRTOS/Demo/RX700_RX71M_RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/RX700_RX71M_RSK_Renesas_e2studio/src/Full_Demo/main_full.c12
-rw-r--r--FreeRTOS/Demo/WIN32-MSVC/main_full.c22
28 files changed, 227 insertions, 544 deletions
diff --git a/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/ReadMe_Instructions.url b/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/ReadMe_Instructions.url
new file mode 100644
index 000000000..7a7ec0e87
--- /dev/null
+++ b/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/ReadMe_Instructions.url
@@ -0,0 +1,5 @@
+[{000214A0-0000-0000-C000-000000000046}]
+Prop3=19,2
+[InternetShortcut]
+URL=http://www.freertos.org/EFM32-Giant-Gecko-Pearl-Gecko-tickless-RTOS-demo.html
+IDList=
diff --git a/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/FreeRTOSConfig.h b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/FreeRTOSConfig.h
index 662b26aef..dc8de7ee6 100644
--- a/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/FreeRTOSConfig.h
+++ b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/FreeRTOSConfig.h
@@ -98,7 +98,7 @@ extern "C" {
* See the comments at the top of main.c, main_full.c and main_low_power.c for
* more information.
*/
-#define configCREATE_LOW_POWER_DEMO 1
+#define configCREATE_LOW_POWER_DEMO 0
/* Some configuration is dependent on the demo being built. */
#if( configCREATE_LOW_POWER_DEMO == 0 )
diff --git a/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/ReadMe_Instructions.url b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/ReadMe_Instructions.url
new file mode 100644
index 000000000..7a7ec0e87
--- /dev/null
+++ b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/ReadMe_Instructions.url
@@ -0,0 +1,5 @@
+[{000214A0-0000-0000-C000-000000000046}]
+Prop3=19,2
+[InternetShortcut]
+URL=http://www.freertos.org/EFM32-Giant-Gecko-Pearl-Gecko-tickless-RTOS-demo.html
+IDList=
diff --git a/FreeRTOS/Demo/CORTEX_M4F_CEC1302_Keil/peripheral_library/cfg.h b/FreeRTOS/Demo/CORTEX_M4F_CEC1302_Keil/peripheral_library/cfg.h
deleted file mode 100644
index 9393aea3c..000000000
--- a/FreeRTOS/Demo/CORTEX_M4F_CEC1302_Keil/peripheral_library/cfg.h
+++ /dev/null
@@ -1,327 +0,0 @@
-/****************************************************************************
-* © 2013 Microchip Technology Inc. and its subsidiaries.
-* You may use this software and any derivatives exclusively with
-* Microchip products.
-* THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS".
-* NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE,
-* INCLUDING ANY IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY,
-* AND FITNESS FOR A PARTICULAR PURPOSE, OR ITS INTERACTION WITH MICROCHIP
-* PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY APPLICATION.
-* IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE,
-* INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND
-* WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP HAS
-* BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE.
-* TO THE FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL
-* CLAIMS IN ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT OF
-* FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
-* MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE
-* OF THESE TERMS.
-*/
-
-/** @defgroup pwm pwm_c_wrapper
- * @{
- */
-/** @file pwm_c_wrapper.cpp
- \brief the pwm component C wrapper
- This program is designed to allow the other C programs to be able to use this component
-
- There are entry points for all C wrapper API implementation
-
-<b>Platform:</b> This is ARC-based component
-
-<b>Toolset:</b> Metaware IDE(8.5.1)
-<b>Reference:</b> smsc_reusable_fw_requirement.doc */
-
-/*******************************************************************************
- * SMSC version control information (Perforce):
- *
- * FILE: $File: //depot_pcs/FWEng/Release/projects/CEC1302_CLIB/release2/Source/hw_blks/common/include/cfg.h $
- * REVISION: $Revision: #1 $
- * DATETIME: $DateTime: 2015/12/23 15:37:58 $
- * AUTHOR: $Author: akrishnan $
- *
- * Revision history (latest first):
- * #1 Branched from //depotAE/projects/Sensor_Fusion/maincodeline/sf01_evb
- * #2 Updated tasks for smbus driver and smbus application
- * #3 Added feature, algo and fusion task
- * #4 Removed smbapp task
- ***********************************************************************************
- */
-
-#ifndef _CFG_H_
-#define _CFG_H_
-
-
-/*
- * TOOLSET : defines the build tools used
- * TOOLKEIL - For KEIL Toolset
- * TOOLPC - For PC Toolset, ex: MSVC++ 6.0,Borland C..etc.
- *
- */
-
-
-#define INTERACTIVE_UART 0
-
-/*
- * TASK_XX : defines the Kernel Task Assignements to Different Application Specific Tasks
- * : Always TASK_00 is High Priority
- * : Ex1: To Assign timer task to TASK_00
- * : #define TASK_00 timer
- * : Ex2: To Assign pwm task to TASK_03
- * : #define TASK_03 pwm
- * : Each Task should have Following Function Definitions
- * : (void) Tasxx_Init_task(void);
- * : (void) Taskxx_Main_task(enum EVENT_TYPE event);
- * : Please refer kernel.h for enum EVENT_TYPE
- * : Ex: If Application needs "tach" task should be added to kernel,
- * : tach.c should contain following public calls:
- * : (void)tach_init_task(void);
- * : (void)tach_main_task(enum EVENT_TYPE event);
- * :
- * : Each Task's event ie. EVENT TASK & EVENT TIMEOUT could be assigned the
- * : priority level. if it is assigned HIGH, then Task's event will belong to
- * : HIGH priority group.
- * : ex: define TASK_04 as pwm and pwm tasks event with following priority list
- * : PRIORITY_TASK_04_EVENTTASK LOW - This means, the pwm task (which is TASK_04) Event Task will be assigned to low priority group
- * : PRIORITY_TASK_04_EVENTTIMEOUT HIGH - This means, the pwm task Event Timeout will be assigned Hihg priority group
- *
- */
-#define LOW 0
-#define HIGH !LOW
-
-#define INTR_ON 1
-#define INTR_OFF 0
-
-#define TASK_SCHED_LO 1
-#define TASK_SCHED_HI 2
-
-#define MAX_NUM_TASKS 31 // Bits 0 - 30
-
-// !!!! CRITICAL !!!
-// You MUST define the following values correctly
-//
-#define NUMBER_OF_TASKS 18 /* Total No: of Enabled Tasks */
-
-#define TASK_00 timer /* TASK_00=timer */
-#define PRIORITY_TASK_00_EVENTTASK HIGH /* Timer Event Task HIGH priority */
-#define PRIORITY_TASK_00_EVENTTIMEOUT HIGH /* Timer Event Timeout HIGH priority */
-#define ENABLE_TASK_00_EVENTINTR 1 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_00_EVENTTASK 0
-#define ENABLE_TASK_00_EVENTTIMER 0
-
-#define TASK_01 spi /* Task_01=spi - for spi */
-#define PRIORITY_TASK_01_EVENTTASK LOW /* Event Task HIGH priority */
-#define PRIORITY_TASK_01_EVENTTIMEOUT LOW /* Event Timeout LOW priority */
-#define ENABLE_TASK_01_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_01_EVENTTASK 0
-#define ENABLE_TASK_01_EVENTTIMER 1
-
-#define TASK_02 smbus /* Task_02=smbus */
-#define PRIORITY_TASK_02_EVENTTASK HIGH /* temp Event Task HIGH priority */
-#define PRIORITY_TASK_02_EVENTTIMEOUT HIGH /* temp Event Timeout LOW priority */
-#define ENABLE_TASK_02_EVENTINTR 1 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_02_EVENTTASK 1
-#define ENABLE_TASK_02_EVENTTIMER 1
-
-#define TASK_03 smbus_app /* TASK_03=smbus_app */
-#define PRIORITY_TASK_03_EVENTTASK HIGH /* Event Task HIGH priority */
-#define PRIORITY_TASK_03_EVENTTIMEOUT HIGH /* Event Timeout HIGH priority */
-#define ENABLE_TASK_03_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_03_EVENTTASK 1
-#define ENABLE_TASK_03_EVENTTIMER 1
-
-#define TASK_04 pwm /* Task_04=pwm */
-#define PRIORITY_TASK_04_EVENTTASK LOW /* Event Task LOW priority */
-#define PRIORITY_TASK_04_EVENTTIMEOUT LOW /* Event Timeout LOW priority */
-#define ENABLE_TASK_04_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_04_EVENTTASK 0
-#define ENABLE_TASK_04_EVENTTIMER 1
-
-#define TASK_05 adc /* TASK_05=adc */
-#define PRIORITY_TASK_05_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_05_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_05_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_05_EVENTTASK 0
-#define ENABLE_TASK_05_EVENTTIMER 1
-
-#define TASK_06 gpio /* TASK_06=gpio */
-#define PRIORITY_TASK_06_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_06_EVENTTIMEOUT HIGH /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_06_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_06_EVENTTASK 0
-#define ENABLE_TASK_06_EVENTTIMER 1
-
-#define TASK_07 btimer /* Task_07=btimer */
-#define PRIORITY_TASK_07_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_07_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_07_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_07_EVENTTASK 0
-#define ENABLE_TASK_07_EVENTTIMER 1
-
-#define TASK_08 led /* Task_08=led */
-#define PRIORITY_TASK_08_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_08_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_08_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_08_EVENTTASK 0
-#define ENABLE_TASK_08_EVENTTIMER 1
-
-#define TASK_09 wdt /* Task_09=wdt */
-#define PRIORITY_TASK_09_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_09_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_09_EVENTINTR 1 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_09_EVENTTASK 1
-#define ENABLE_TASK_09_EVENTTIMER 1
-
-#define TASK_10 aes /* Task_10=aes */
-#define PRIORITY_TASK_10_EVENTTASK LOW /* phot Event Task LOW priority */
-#define PRIORITY_TASK_10_EVENTTIMEOUT LOW /* phot Event Timeout LOW priority */
-#define ENABLE_TASK_10_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_10_EVENTTASK 0
-#define ENABLE_TASK_10_EVENTTIMER 1
-
-#define TASK_11 rnd /* Task_11=rnd */
-#define PRIORITY_TASK_11_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_11_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_11_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_11_EVENTTASK 0
-#define ENABLE_TASK_11_EVENTTIMER 1
-
-#define TASK_12 sha /* Task_12=sha */
-#define PRIORITY_TASK_12_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_12_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_12_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_12_EVENTTASK 0
-#define ENABLE_TASK_12_EVENTTIMER 1
-
-#define TASK_13 pke /* Task_13=pke */
-#define PRIORITY_TASK_13_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_13_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_13_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_13_EVENTTASK 0
-#define ENABLE_TASK_13_EVENTTIMER 1
-
-#define TASK_14 tach /* Task_14=tach */
-#define PRIORITY_TASK_14_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_14_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_14_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_14_EVENTTASK 0
-#define ENABLE_TASK_14_EVENTTIMER 1
-
-#define TASK_15 rtc /* Task_15=rtc */
-#define PRIORITY_TASK_15_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_15_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_15_EVENTINTR 1 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_15_EVENTTASK 0
-#define ENABLE_TASK_15_EVENTTIMER 1
-
-#define TASK_16 htimer /* TASK_06=htimer */
-#define PRIORITY_TASK_16_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_16_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_16_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_16_EVENTTASK 0
-#define ENABLE_TASK_16_EVENTTIMER 1
-
-#define TASK_17 uart /* Task_17=uart */
-#define PRIORITY_TASK_17_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_17_EVENTTIMEOUT HIGH /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_17_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_17_EVENTTASK 0
-#define ENABLE_TASK_17_EVENTTIMER 1
-
-#define TASK_18 dflt /* Task_18=dflt */
-#define PRIORITY_TASK_18_EVENTTASK LOW /* Dflt Event Task LOW priority */
-#define PRIORITY_TASK_18_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-#define ENABLE_TASK_18_EVENTINTR 1 /* Enable EventTypeInterrupt scheduling */
-#define ENABLE_TASK_18_EVENTTASK 1
-#define ENABLE_TASK_18_EVENTTIMER 1
-
-//#define TASK_19 dflt /* Task_19=dflt */
-//#define PRIORITY_TASK_19_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_19_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_19_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_19_EVENTTASK 0
-//#define ENABLE_TASK_19_EVENTTIMER 0
-
-//#define TASK_20 dflt /* Task_20=dflt */
-//#define PRIORITY_TASK_20_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_20_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_20_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_20_EVENTTASK 0
-//#define ENABLE_TASK_20_EVENTTIMER 0
-
-//#define TASK_21 dflt /* Task_21=dflt */
-//#define PRIORITY_TASK_21_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_21_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_21_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_21_EVENTTASK 0
-//#define ENABLE_TASK_21_EVENTTIMER 0
-
-//#define TASK_22 dflt /* Task_22=dflt */
-//#define PRIORITY_TASK_22_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_22_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_22_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_22_EVENTTASK 0
-//#define ENABLE_TASK_22_EVENTTIMER 0
-
-//#define TASK_23 dflt /* Task_23=dflt */
-//#define PRIORITY_TASK_23_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_23_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_23_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_23_EVENTTASK 0
-//#define ENABLE_TASK_23_EVENTTIMER 0
-
-//#define TASK_24 dflt /* Task_24=dflt */
-//#define PRIORITY_TASK_24_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_24_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_24_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_24_EVENTTASK 0
-//#define ENABLE_TASK_24_EVENTTIMER 0
-
-//#define TASK_25 dflt /* Task_25=dflt */
-//#define PRIORITY_TASK_25_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_25_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_25_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_25_EVENTTASK 0
-//#define ENABLE_TASK_25_EVENTTIMER 0
-
-//#define TASK_26 dflt /* Task_26=dflt */
-//#define PRIORITY_TASK_26_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_26_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_26_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_26_EVENTTASK 0
-//#define ENABLE_TASK_26_EVENTTIMER 0
-
-//#define TASK_27 dflt /* Task_27=dflt */
-//#define PRIORITY_TASK_27_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_27_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_27_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_27_EVENTTASK 0
-//#define ENABLE_TASK_27_EVENTTIMER 0
-
-//#define TASK_28 dflt /* Task_28=dflt */
-//#define PRIORITY_TASK_28_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_28_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_28_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_28_EVENTTASK 0
-//#define ENABLE_TASK_28_EVENTTIMER 0
-
-//#define TASK_29 dflt /* Task_29=dflt */
-//#define PRIORITY_TASK_29_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_29_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_29_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_29_EVENTTASK 0
-//#define ENABLE_TASK_29_EVENTTIMER 0
-
-//#define TASK_30 dflt /* Task_30=dflt */
-//#define PRIORITY_TASK_30_EVENTTASK LOW /* Dflt Event Task LOW priority */
-//#define PRIORITY_TASK_30_EVENTTIMEOUT LOW /* Dflt Event Timeout LOW priority */
-//#define ENABLE_TASK_30_EVENTINTR 0 /* Enable EventTypeInterrupt scheduling */
-//#define ENABLE_TASK_30_EVENTTASK 0
-//#define ENABLE_TASK_30_EVENTTIMER 0
-
-
-#endif /*_CFG_H_*/
-
-/** @}
- */
-
diff --git a/FreeRTOS/Demo/RX100_RX113-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX100_RX113-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
index 71f025f57..0239a86de 100644
--- a/FreeRTOS/Demo/RX100_RX113-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX100_RX113-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
@@ -158,14 +158,14 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( tskIDLE_PRIORITY + 1 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/RX100_RX113-RSK_Renesas_e2studio/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX100_RX113-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
index 58c096dcb..ba50e8acf 100644
--- a/FreeRTOS/Demo/RX100_RX113-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX100_RX113-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
@@ -156,14 +156,14 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( tskIDLE_PRIORITY + 1 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/RX200_RX231-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX200_RX231-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
index f23431380..aa2514753 100644
--- a/FreeRTOS/Demo/RX200_RX231-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX200_RX231-RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
@@ -148,14 +148,14 @@
#define mainCHECK_TASK_PRIORITY ( configMAX_PRIORITIES - 1 )
#define mainQUEUE_OVERWRITE_PRIORITY ( tskIDLE_PRIORITY )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/RX200_RX231-RSK_Renesas_e2studio/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX200_RX231-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
index 8b0bfee14..d2ccb7c51 100644
--- a/FreeRTOS/Demo/RX200_RX231-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX200_RX231-RSK_Renesas_e2studio/src/Full_Demo/main_full.c
@@ -148,14 +148,14 @@
#define mainCHECK_TASK_PRIORITY ( configMAX_PRIORITIES - 1 )
#define mainQUEUE_OVERWRITE_PRIORITY ( tskIDLE_PRIORITY )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/RX700_RX71M_RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX700_RX71M_RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
index a2150c100..394f6c97c 100644
--- a/FreeRTOS/Demo/RX700_RX71M_RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX700_RX71M_RSK_GCC_e2studio_IAR/src/Full_Demo/main_full.c
@@ -159,14 +159,14 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/RX700_RX71M_RSK_Renesas_e2studio/src/Full_Demo/main_full.c b/FreeRTOS/Demo/RX700_RX71M_RSK_Renesas_e2studio/src/Full_Demo/main_full.c
index 6c46b2033..a5a19e710 100644
--- a/FreeRTOS/Demo/RX700_RX71M_RSK_Renesas_e2studio/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/RX700_RX71M_RSK_Renesas_e2studio/src/Full_Demo/main_full.c
@@ -159,14 +159,14 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
diff --git a/FreeRTOS/Demo/WIN32-MSVC/main_full.c b/FreeRTOS/Demo/WIN32-MSVC/main_full.c
index c8f694a2d..efa214730 100644
--- a/FreeRTOS/Demo/WIN32-MSVC/main_full.c
+++ b/FreeRTOS/Demo/WIN32-MSVC/main_full.c
@@ -309,10 +309,10 @@ const TickType_t xCycleFrequency = pdMS_TO_TICKS( 2500UL );
{
pcStatusMessage = "Error: EventGroup";
}
- else if( xAreIntegerMathsTaskStillRunning() != pdTRUE )
- {
+ else if( xAreIntegerMathsTaskStillRunning() != pdTRUE )
+ {
pcStatusMessage = "Error: IntMath";
- }
+ }
else if( xAreGenericQueueTasksStillRunning() != pdTRUE )
{
pcStatusMessage = "Error: GenQueue";
@@ -325,20 +325,20 @@ const TickType_t xCycleFrequency = pdMS_TO_TICKS( 2500UL );
{
pcStatusMessage = "Error: BlockQueue";
}
- else if( xAreSemaphoreTasksStillRunning() != pdTRUE )
- {
+ else if( xAreSemaphoreTasksStillRunning() != pdTRUE )
+ {
pcStatusMessage = "Error: SemTest";
- }
- else if( xArePollingQueuesStillRunning() != pdTRUE )
- {
+ }
+ else if( xArePollingQueuesStillRunning() != pdTRUE )
+ {
pcStatusMessage = "Error: PollQueue";
- }
+ }
else if( xAreMathsTaskStillRunning() != pdPASS )
{
pcStatusMessage = "Error: Flop";
}
- else if( xAreRecursiveMutexTasksStillRunning() != pdTRUE )
- {
+ else if( xAreRecursiveMutexTasksStillRunning() != pdTRUE )
+ {
pcStatusMessage = "Error: RecMutex";
}
else if( xAreCountingSemaphoreTasksStillRunning() != pdTRUE )
diff --git a/FreeRTOS/Demo/CORTEX_A53_64-bit_UltraScale_MPSoC/RTOSDemo_A53/src/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_A53_64-bit_UltraScale_MPSoC/RTOSDemo_A53/src/Full_Demo/main_full.c
index 34ed90ff2..5a7bbceea 100644
--- a/FreeRTOS/Demo/CORTEX_A53_64-bit_UltraScale_MPSoC/RTOSDemo_A53/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A53_64-bit_UltraScale_MPSoC/RTOSDemo_A53/src/Full_Demo/main_full.c
@@ -145,20 +145,20 @@
#define mainCOM_TEST_TASK_PRIORITY ( tskIDLE_PRIORITY + ( UBaseType_t ) 2 )
#define mainCHECK_TASK_PRIORITY ( configMAX_PRIORITIES - ( UBaseType_t ) 1 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( ( TickType_t ) 0 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( ( TickType_t ) 5000 )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( ( TickType_t ) ( 200 ) )
/* Parameters that are passed into the register check tasks solely for the
@@ -392,7 +392,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -415,7 +415,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -145,20 +145,20 @@
#define mainCOM_TEST_TASK_PRIORITY ( tskIDLE_PRIORITY + ( UBaseType_t ) 2 )
#define mainCHECK_TASK_PRIORITY ( configMAX_PRIORITIES - ( UBaseType_t ) 1 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_A5_SAMA5D3x_Xplained_IAR/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_A5_SAMA5D3x_Xplained_IAR/Full_Demo/main_full.c
index 81524873f..bef7de92f 100644
--- a/FreeRTOS/Demo/CORTEX_A5_SAMA5D3x_Xplained_IAR/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A5_SAMA5D3x_Xplained_IAR/Full_Demo/main_full.c
@@ -154,21 +154,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -427,7 +427,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -450,7 +450,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -154,21 +154,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_A5_SAMA5D4x_EK_IAR/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_A5_SAMA5D4x_EK_IAR/Full_Demo/main_full.c
index 17c863c92..09b7032c6 100644
--- a/FreeRTOS/Demo/CORTEX_A5_SAMA5D4x_EK_IAR/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A5_SAMA5D4x_EK_IAR/Full_Demo/main_full.c
@@ -154,21 +154,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -427,7 +427,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -450,7 +450,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -154,21 +154,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_A9_Cyclone_V_SoC_DK/main_full.c b/FreeRTOS/Demo/CORTEX_A9_Cyclone_V_SoC_DK/main_full.c
index a599075a4..036d670b3 100644
--- a/FreeRTOS/Demo/CORTEX_A9_Cyclone_V_SoC_DK/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A9_Cyclone_V_SoC_DK/main_full.c
@@ -148,21 +148,21 @@
uses the Altera polling UART driver - so *must* run at the idle priority. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( tskIDLE_PRIORITY )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -416,7 +416,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -439,7 +439,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -148,21 +148,21 @@
uses the Altera polling UART driver - so *must* run at the idle priority. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( tskIDLE_PRIORITY )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_A9_RZ_R7S72100_IAR_DS-5/Source/Full-Demo/main_full.c b/FreeRTOS/Demo/CORTEX_A9_RZ_R7S72100_IAR_DS-5/Source/Full-Demo/main_full.c
index ffce5ab61..f45b8e4e6 100644
--- a/FreeRTOS/Demo/CORTEX_A9_RZ_R7S72100_IAR_DS-5/Source/Full-Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A9_RZ_R7S72100_IAR_DS-5/Source/Full-Demo/main_full.c
@@ -180,7 +180,7 @@ to be fitted to the UART port. */
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
@@ -191,15 +191,15 @@ the COM test tasks, so just set both to invalid values. */
#define mainCOM_TEST_LED ( 100 )
#define mainBAUD_RATE ( 0 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -487,7 +487,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -510,7 +510,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -180,7 +180,7 @@ to be fitted to the UART port. */
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_A9_Zynq_ZC702/RTOSDemo/src/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_A9_Zynq_ZC702/RTOSDemo/src/Full_Demo/main_full.c
index c11359477..91cbf6a9c 100644
--- a/FreeRTOS/Demo/CORTEX_A9_Zynq_ZC702/RTOSDemo/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_A9_Zynq_ZC702/RTOSDemo/src/Full_Demo/main_full.c
@@ -167,21 +167,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -469,7 +469,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -492,7 +492,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -167,21 +167,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/Full_Demo/main_full.c
index 7888273ed..5f382cebe 100644
--- a/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_EFM32_Giant_Gecko_Simplicity_Studio/Full_Demo/main_full.c
@@ -142,14 +142,14 @@
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
@@ -366,7 +366,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -384,7 +384,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/Full_Demo/main_full.c
index 7888273ed..5f382cebe 100644
--- a/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_EFM32_Pearl_Gecko_Simplicity_Studio/Full_Demo/main_full.c
@@ -142,14 +142,14 @@
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
@@ -366,7 +366,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -384,7 +384,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/CORTEX_M4F_MSP432_LaunchPad_IAR_CCS_Keil/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M4F_MSP432_LaunchPad_IAR_CCS_Keil/Full_Demo/main_full.c
index 6a032e0b2..dec16d522 100644
--- a/FreeRTOS/Demo/CORTEX_M4F_MSP432_LaunchPad_IAR_CCS_Keil/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M4F_MSP432_LaunchPad_IAR_CCS_Keil/Full_Demo/main_full.c
@@ -157,14 +157,14 @@
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD ( pdMS_TO_TICKS( 3000UL ) )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
#define mainERROR_CHECK_TASK_PERIOD ( pdMS_TO_TICKS( 200UL ) )
/* Parameters that are passed into the register check tasks solely for the
@@ -412,7 +412,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -430,7 +430,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/CORTEX_M7_SAME70_Xplained_AtmelStudio/src/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M7_SAME70_Xplained_AtmelStudio/src/Full_Demo/main_full.c
index 653d98f50..0f358f1f5 100644
--- a/FreeRTOS/Demo/CORTEX_M7_SAME70_Xplained_AtmelStudio/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M7_SAME70_Xplained_AtmelStudio/src/Full_Demo/main_full.c
@@ -143,15 +143,15 @@
#define mainCHECK_TASK_PRIORITY ( configMAX_PRIORITIES - 1 )
#define mainQUEUE_OVERWRITE_PRIORITY ( tskIDLE_PRIORITY )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -396,7 +396,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -414,7 +414,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_AtmelStudio/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_AtmelStudio/Full_Demo/main_full.c
index 7d56771bd..00cfd9fc1 100644
--- a/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_AtmelStudio/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_AtmelStudio/Full_Demo/main_full.c
@@ -149,21 +149,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -399,7 +399,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -417,7 +417,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -149,21 +149,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_IAR_Keil/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_IAR_Keil/Full_Demo/main_full.c
index 7d56771bd..00cfd9fc1 100644
--- a/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_IAR_Keil/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M7_SAMV71_Xplained_IAR_Keil/Full_Demo/main_full.c
@@ -149,21 +149,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -399,7 +399,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -417,7 +417,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -149,21 +149,21 @@
/* The initial priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 0 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
index b265a294c..88818a693 100644
--- a/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
@@ -148,15 +148,15 @@
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -411,7 +411,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -429,7 +429,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/CORTEX_R4F_RZ_T_GCC_IAR/src/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_R4F_RZ_T_GCC_IAR/src/Full_Demo/main_full.c
index bd848b0a0..20a6da1a4 100644
--- a/FreeRTOS/Demo/CORTEX_R4F_RZ_T_GCC_IAR/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_R4F_RZ_T_GCC_IAR/src/Full_Demo/main_full.c
@@ -158,14 +158,14 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the portTICK_PERIOD_MS constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+portTICK_PERIOD_MS constant. */
#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
@@ -442,7 +442,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -465,7 +465,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
diff --git a/FreeRTOS/Demo/MicroBlaze_Kintex7_EthernetLite/RTOSDemo/src/Full_Demo/main_full.c b/FreeRTOS/Demo/MicroBlaze_Kintex7_EthernetLite/RTOSDemo/src/Full_Demo/main_full.c
index d866023a7..1b06ef244 100644
--- a/FreeRTOS/Demo/MicroBlaze_Kintex7_EthernetLite/RTOSDemo/src/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/MicroBlaze_Kintex7_EthernetLite/RTOSDemo/src/Full_Demo/main_full.c
@@ -155,21 +155,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 7 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
#define mainNO_ERROR_CHECK_TASK_PERIOD ( pdMS_TO_TICKS( 3000UL ) )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
#define mainERROR_CHECK_TASK_PERIOD ( pdMS_TO_TICKS( 200UL ) )
/* Parameters that are passed into the register check tasks solely for the
@@ -413,7 +413,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -431,7 +431,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -155,21 +155,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 7 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/RX600_RX64M_RSK_GCC_e2studio/src/main_full.c b/FreeRTOS/Demo/RX600_RX64M_RSK_GCC_e2studio/src/main_full.c
index 2569fc00a..8bbb5a28d 100644
--- a/FreeRTOS/Demo/RX600_RX64M_RSK_GCC_e2studio/src/main_full.c
+++ b/FreeRTOS/Demo/RX600_RX64M_RSK_GCC_e2studio/src/main_full.c
@@ -149,21 +149,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 3 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -409,7 +409,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -427,7 +427,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -149,21 +149,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 3 )
/* A block time of zero simply means "don't block". */
diff --git a/FreeRTOS/Demo/RX600_RX64M_RSK_Renesas_e2studio/Source/main_full.c b/FreeRTOS/Demo/RX600_RX64M_RSK_Renesas_e2studio/Source/main_full.c
index b899e311b..7fe474f8e 100644
--- a/FreeRTOS/Demo/RX600_RX64M_RSK_Renesas_e2studio/Source/main_full.c
+++ b/FreeRTOS/Demo/RX600_RX64M_RSK_Renesas_e2studio/Source/main_full.c
@@ -149,21 +149,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
/* The LED used by the check timer. */
#define mainCHECK_LED ( 3 )
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -409,7 +409,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -427,7 +427,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -149,21 +149,21 @@
/* The priority used by the UART command console task. */
#define mainUART_COMMAND_CONSOLE_TASK_PRIORITY ( configMAX_PRIORITIES - 2 )
-/* The LED used by the check timer. */
+/* The LED used by the check task. */
#define mainCHECK_LED ( 3 )
/* A block time of zero simply means "don't block". */